@@ -322,6 +322,13 @@ class ObservedDict(abc.MutableMapping):
     def __getitem__(self, k: Any) -> Any:
         return self.value[k]
 
+    # This should be posititional only but flake8 doesn't like that
+    def get(self, key: str, default: Any = None) -> Any:
+        """Return the value for key if key is in the dictionary, else default."""
+        return self.value.get(
+            key, item_to_observed(_get_set_cb(db=self, k=key), default)
+        )
+
     def __setitem__(self, k: Any, v: Any) -> None:
         self.value[k] = v
         self.on_mutate()
