@@ -6,9 +6,9 @@ import os
 import flask
 from werkzeug.local import LocalProxy
 
-from .app import debug, ReplitAuthContext, run, run_app
+from .app import debug, ReplitAuthContext, run
 from .user import User, UserStore
 from .utils import *
 from ..database import AsyncDatabase, Database, db
 
-auth = LocalProxy(lambda: ReplitAuthContext(flask.request.headers))
+auth = LocalProxy(lambda: ReplitAuthContext.from_headers(flask.request.headers))
